'use strict';

const stylesheetInjector = require('stylesheet-injector');

const optionsNormilizer = require('./lib/normalize-options');
const createElement = require('./lib/create-element');
const styles = require('./lib/style.json');
const guid = require('./lib/guid.json');

module.exports = Textinput;

/**
 * @constructor
 * @param {Object} options - Configuration object (See documentation)
 */
function Textinput (options) {
  if (!(this instanceof Textinput)) return new Textinput(options);
  const config = optionsNormilizer(options);
  this.config = config;
  this.element = createElement(config);
  this.element.instance = this;
  this.isValid = true;
  stylesheetInjector(`ui-textinput-${guid}`, styles);
}

/**
 * @member Give the input element the focus
 */
Textinput.prototype.focus = function () {
  this.element.focus();
};

/**
 * @member Set the element's value
 * @param {String} val - Value to set
 */
Textinput.prototype.setValue = function (val) {
  this.element.value = val;
  this.config.onValueChange.forEach(f => {
    f(this.element.value);
  });
};

/**
 * @member Get the element's current value
 * @return {String}
 */
Textinput.prototype.getValue = function () {
  return this.element.value;
};

/**
 * @member Disable the input element
 */
Textinput.prototype.disable = function () {
  this.element.setAttribute('disabled', true);
  this.element.classList.add(`ui-textinput-${guid}--disabled`);
};

/**
 * @member Enable the input element
 */
Textinput.prototype.enable = function () {
  this.element.removeAttribute('disabled');
  this.element.classList.remove(`ui-textinput-${guid}--disabled`);
};
