'use strict';

const guid = require('./guid.json');

/**
 * Create DOM element
 * @param {Object} config - Configuration Object
 * @return {HTMLInputElement}
 */
module.exports = function (config) {
  const element = document.createElement('input');
  element.setAttribute('type', config.type);
  element.setAttribute('tabindex', config.tabindex);
  element.className = `ui-textinput-${guid}`;
  element.style.width = config.width;
  element.addEventListener('input', onInput, false);

  return element;
};

/**
 * Handler for 'input' event
 * @private
 */
function onInput () {
  const val = this.value;
  this.instance.config.onValueChange.forEach(f => { f(val); });
  const isNewValueValid = this.instance.config.validator(val);
  if (this.instance.isValid !== isNewValueValid) {
    this.instance.isValid = isNewValueValid;
    this.instance.config.onValidationStatusChange.forEach(f => {
      f(isNewValueValid);
    });
  }
}
