'use strict';

const test = require('tape');
const proxyquire = require('proxyquire').noPreserveCache();
const sinon = require('sinon');

/**
 * Helpers
 */

function getSelfStub () {
  return proxyquire('../lib/normalize-options', {
    'delegate-normalizer': delegateNormalizerStub
  });
}

/**
 * Fakes
 */

const delegateNormalizerStub = function () {};

/**
 * TESTS
 */

test('normalize-options > main > Called', t => {
  const delegateNormalizerSpy = sinon.spy(delegateNormalizerStub);
  const selfStub = proxyquire('../lib/normalize-options', {
    'delegate-normalizer': delegateNormalizerSpy
  });
  const optionsStub = {};

  const result = selfStub(optionsStub);

  t.ok(typeof result === 'object', 'Returns object');
  t.ok(delegateNormalizerSpy.calledTwice,
    'Delegate normalizer is called 2 times');
  t.end();
});

test('normalize-options > main > Options do not contain width', t => {
  const selfStub = getSelfStub();
  const optionsStub = {};

  const result = selfStub(optionsStub);

  t.ok(result.width === '100%', 'width property is set to "100%"');
  t.end();
});

test('normalize-options > main > options.width is not a string', t => {
  const selfStub = getSelfStub();
  const optionsStub = {
    width: 1
  };

  const result = selfStub(optionsStub);

  t.ok(result.width === '100%', 'width property is set to "100%"');
  t.end();
});

test('normalize-options > main > options.width is a string', t => {
  const WIDTH_VALUE = 'some_string';
  const selfStub = getSelfStub();
  const optionsStub = {
    width: WIDTH_VALUE
  };

  const result = selfStub(optionsStub);

  t.ok(result.width === WIDTH_VALUE, 'width property is not transformed');
  t.end();
});

test('normalize-options > main > options.validator is not a function', t => {
  const selfStub = getSelfStub();
  const optionsStub = {
    validator: 'some_string'
  };

  const result = selfStub(optionsStub);

  t.ok(typeof result.validator === 'function',
    'validator property is set to a function');
  t.end();
});
